=================
AEAT-WEB-SERVICES
=================

.. list-table::

    * - Master
      - .. image:: https://travis-ci.org/initios/aeat-web-services.svg?branch=master
            :target: https://travis-ci.org/initios/aeat-web-services
      - .. image:: https://coveralls.io/repos/github/initios/aeat-web-services/badge.svg?branch=master
            :target: https://coveralls.io/github/initios/aeat-web-services?branch=master


Prerequisites
=============

Install xmlsec prerequisites.
Check https://github.com/mehcode/python-xmlsec


Install
=======

.. code:: console

    $ pip install aeat-web-services


Develop
=======

.. code:: console

    $ pip install -e .
    $ pip install -r requirements_test.txt


Testing
=======

.. code:: console

    $ pip install tox
    $ tox


Changelog
=========

.. list-table::

    * - 2018-04-01 Release 1.0.0-pre.1
      - Versión inicial

